@@ -6,9 +6,9 @@
 SEXP Cairo_get_serial(SEXP dev);
 SEXP Cairo_set_onSave(SEXP dev, SEXP fn);
 SEXP Rcairo_capture(SEXP dev);
-SEXP Rcairo_initialize();
+SEXP Rcairo_initialize(void);
 SEXP Rcairo_snapshot(SEXP dev, SEXP sLast);
-SEXP Rcairo_supported_types();
+SEXP Rcairo_supported_types(void);
 SEXP get_img_backplane(SEXP dev);
 SEXP ptr_to_raw(SEXP ptr, SEXP off, SEXP len);
 SEXP raw_to_ptr(SEXP ptr, SEXP woff, SEXP raw, SEXP roff, SEXP len);
